clear 
eststo clear
set more off
cap cd "R:\Zentrale\ZB-F\Daten\F 1\Projekte\Abbassi-Tischer\Data"

cap ssc install reghdfe
cap ssc install winsor
cap ssc install outreg2
cap ssc install tuples
/*also cgmreg.dao is needed. Copy text at http://gelbach.law.upenn.edu/~gelbach/ado/cgmreg.ado and store it as an .ado file in the stata ado/plus/c/ folder*/

use submission.dta, replace

**************************************************************************************************************************************
global SE "robust" 										/*"Robust SE*/
global SE1 "cluster bankid tdate" 						/*Double Clustered SE (Bank and Day)*/
global FE  "bankid#group2#timeframe_indicator tdate"	/*Bank borrower/lender/period day FE*/ 	
global FE2 "bankid#group2#timeframe_indicator"			/*Bank borrower/lender/period FE*/

global liqu1 "c.drate_diff_as_ab"						/*daily aggressive sell buy spread*/
global liqu2 "c.abs_as_ab"								/*daily absolute aggressive sell buy spread*/
global liqu3 "c.damihud"								/*daily amihud ratio*/
global liqu4 "c.roll2"									/*daily Roll's (1984) bid-ask spread*/
global liqu5 "c.sd_ir"									/*daily intraday standard deviation*/

global liqu1_1 "c.drate_diff_as_ab_nac"					/*afternoon aggressive sell buy sprad*/
global liqu2_1 "c.abs_as_ab_nach"						/*afternoon absolute aggressive sell buy spread*/
global liqu3_1 "c.amihud_nach"							/*afternoon amihud ratio*/
global liqu4_1 "c.roll2_nach"							/*afternoon ROll's (1984) bid-ask spread*/
global liqu5_1 "c.sd_ir_nach"							/*afternoon intraday standard deviation*/

global periods "c.crisis c.LTRO" 						/*period controls*/
global periods2 "c.LTRO" 
global seasonal "c.end_of_rmp c.end_month c.end_year"	/*seasonal controls*/

global control0a "c.agg_sell_dummy"						/*dummy indication aggressive sell trades*/
global control0b "c.amount"								/*daily aggregate trade amount*/
global control1 "c.rtgs_net"							/*rtgs volume net of gc pooling volume*/
global control2 "c.interm2"								/*intermediation ratio*/
global control3 "c.sh_amount_s_a"						/*daily share of aggressive sell trades*/
global control4 "c.wedge"								/*interest rate wedge unsecured-secured*/
global control5 "c.oisspread"							/*Euribor-OIS spread*/
global control6 "c.marginallending"						/*marginallending facility*/
global control7 "c.trading_pattern"						/*aggregate trading amounts morning/afteroon*/
global control8 "c.volwedge"							/*traded volume wedge unsecured-secured*/
global control9 "c.sh_amount_b_a"						/*daily share of aggressive buy trades*/
global control10 "c.mro_ir"								/*main refinancing rate*/
global control11 "c.drate_av_vol"						/*volume weighted daily average rate*/
global control12 "c.drate_av"							/*daily average rate*/

foreach x in as_ab abs_as_ab amihud roll2 sd_ir {
local j = `j'+1
global liqu`j'a "c.`x'_vn"								/*morning - afternoon illiquidity measure*/
global liqu`j'd "c.`x'_nv"								/*afternoon - morning illiquidity measure*/
global liqu`j'help1 "c.`x'_liqdrop"						/*dummy indicating an intraday liquidity drop*/
global liqu`j'help2 "c.`x'_liqrise"						/*dummy indicating an intraday liquidity rise*/
}

********************************************************************************************************************************************************************************************************************************************************************
********************************************************************************************************************************************************************************************************************************************************************
*Step 2: The Relation between Market Illiquidity and the Intraday Rate
********************************************************************************************************************************************************************************************************************************************************************
********************************************************************************************************************************************************************************************************************************************************************

**********************************************************************************************************************************
**********************************************************************************************************************************
*With Robust Standard Errors and additional controls
**********************************************************************************************************************************
**********************************************************************************************************************************

forvalues j = 1/5 {
local h1 = "$" + "liqu" + "`j'"			/*for daily liquidity measures*/
local h2 = "$" + "liqu" + "`j'" + "_1"	/*for afternoon liquidity measures*/
*baseline table
reghdfe rate_wins 		nachmittag c.nachmittag#`h2' if amihud_nach<100, absorb(tdate) vce($SE)  old 
est sto t2_1a`j'
reghdfe rate_wins 		nachmittag c.nachmittag#`h2' if amihud_nach<100, absorb($FE) vce($SE)  old 
est sto t2_1b`j'
reghdfe rate_wins 		nachmittag c.nachmittag#(`h2' $periods) if amihud_nach<100, absorb($FE) vce($SE)  old
est sto t2_1c`j'
reghdfe rate_wins 		nachmittag c.nachmittag#(`h2' $periods $seasonal) if amihud_nach<100, absorb($FE) vce($SE)  old
est sto t2_1d`j'
reghdfe rate_wins 	 	nachmittag c.nachmittag#(`h2'#(c.pre c.crisis c.LTRO) $periods $seasonal) if amihud_nach<100, absorb($FE) vce($SE)  old
est sto t2_1e`j'
reghdfe rate_wins	nachmittag c.nachmittag#(`h2'#(c.pre c.crisis c.LTRO) $control0a $control0b $control1 $control2 $control3 $control4 $control5 $control6 $control7 $periods $seasonal) if amihud_nach<100, absorb($FE) vce($SE)  old
est sto t2_1f`j'
*robustness table
reghdfe rate_wins 	ext	c.ext#($periods2) nachmittag c.nachmittag#(`h2' c.ext c.ext#($periods2) $periods $seasonal) if amihud_nach<100, absorb($FE) vce($SE)  old
est sto t2_5a`j'
reghdfe rate_wins 	ext	c.ext#($periods2) nachmittag `h2'#c.ext c.nachmittag#(`h2' `h2'#c.ext c.ext c.ext#($periods2)  $periods $seasonal) if amihud_nach<100, absorb($FE) vce($SE)  old
est sto t2_5b`j'
reghdfe rate_wins nachmittag c.nachmittag#(`h2' $seasonal) if amihud_nach<100 & LTRO==1, absorb($FE) vce($SE)  old
est sto t2_5c`j'
reghdfe rate_wins nachmittag c.nachmittag#(`h2' $seasonal) if amihud_nach<100 & LTRO1y==1, absorb($FE) vce($SE)  old
est sto t2_5d1`j'
reghdfe rate_wins nachmittag c.nachmittag#(`h2' $seasonal) if amihud_nach<100 & LTRO3y==1, absorb($FE) vce($SE)  old
est sto t2_5d2`j'
reghdfe rate_wins 		c.nachmittag##(`h2' $control12 $periods $seasonal) if amihud_nach<100, absorb($FE2) vce($SE)  old
est sto t2_5e`j'
reghdfe rate_wins 		c.nachmittag##(`h1' $control12 $periods $seasonal) if damihud<500 & amihud_nach<100, absorb($FE2) vce($SE)  old
est sto t2_5f`j'
local h6 = "$" + "liqu" + "`j'" + "a"
local h7 = "$" + "liqu" + "`j'" + "d"
local h8 = "$" + "liqu" + "`j'" + "help1"
local h9 = "$" + "liqu" + "`j'" + "help2"
reghdfe rate_wins 		nachmittag c.nachmittag#(`h6'#`h8' `h6'#`h9' $periods $seasonal) if  amihud_nach<100, absorb($FE) vce($SE)  old
est sto t2_5g`j'
}

*step 2 baseline
outreg2 [t2_1a3 t2_1b3 t2_1c3 t2_1d3 t2_1e3 t2_1f3] using "R:\Zentrale\ZB-F\Daten\F 1\Projekte\Abbassi-Tischer\Replication\Tables\step2_robustSE_baseline", stats(coef se) e(r2_within)   replace excel alpha(0.01, 0.05) symbol(**, *)
outreg2 [t2_1a1 t2_1a2 t2_1a4 t2_1a5 t2_1b1 t2_1b2 t2_1b4 t2_1b5 t2_1c1 t2_1c2 t2_1c4 t2_1c5 t2_1d1 t2_1d2 t2_1d4 t2_1d5 t2_1e1 t2_1e2 t2_1e4 t2_1e5 t2_1f1 t2_1f2 t2_1f4 t2_1f5] using "R:\Zentrale\ZB-F\Daten\F 1\Projekte\Abbassi-Tischer\Replication\Tables\step2_robustSE_baseline_otherliqu", stats(coef se) e(r2_within)   replace excel alpha(0.01, 0.05) symbol(**, *)

*step 2 robustness
outreg2 [t2_5a3 t2_5b3 t2_5c3 t2_5d13 t2_5d23 t2_5e3 t2_5f3 t2_5g3] using "R:\Zentrale\ZB-F\Daten\F 1\Projekte\Abbassi-Tischer\Replication\Tables\step2_robustSE_robust", stats(coef se) e(r2_within)   replace excel alpha(0.01, 0.05) symbol(**, *)
outreg2 [t2_5a1 t2_5a2 t2_5a4 t2_5a5 t2_5b1 t2_5b2 t2_5b4 t2_5b5 t2_5c1 t2_5c2 t2_5c4 t2_5c5 t2_5d11 t2_5d12  t2_5d14 t2_5d15 t2_5d21 t2_5d22  t2_5d24 t2_5d25 t2_5e1 t2_5e2 t2_5e4 t2_5e5 t2_5f1 t2_5f2 t2_5f4 t2_5f5 t2_5g1 t2_5g2 t2_5g4 t2_5g5] using "R:\Zentrale\ZB-F\Daten\F 1\Projekte\Abbassi-Tischer\Replication\Tables\step2_robustSE_robust_otherliqu", stats(coef se) e(r2_within)   replace excel alpha(0.01, 0.05) symbol(**, *)

**********************************************************************************************************************************
**********************************************************************************************************************************
*With Double-Clustered Standard Errors (bank and day) and additional controls
**********************************************************************************************************************************
**********************************************************************************************************************************

*With Double Clustering and additional controls
forvalues j = 1/5 {
local h1 = "$" + "liqu" + "`j'"			/*for daily liquidity measures*/
local h2 = "$" + "liqu" + "`j'" + "_1"	/*for afternoon liquidity measures*/
*baseline table
reghdfe rate_wins 		nachmittag c.nachmittag#`h2' if amihud_nach<100, absorb(tdate) vce($SE1)  old 
est sto t2_1a`j'
reghdfe rate_wins 		nachmittag c.nachmittag#`h2' if amihud_nach<100, absorb($FE) vce($SE1)  old 
est sto t2_1b`j'
reghdfe rate_wins 		nachmittag c.nachmittag#(`h2' $periods) if amihud_nach<100, absorb($FE) vce($SE1)  old
est sto t2_1c`j'
reghdfe rate_wins 		nachmittag c.nachmittag#(`h2' $periods $seasonal) if amihud_nach<100, absorb($FE) vce($SE1)  old
est sto t2_1d`j'
reghdfe rate_wins 	 	nachmittag c.nachmittag#(`h2'#(c.pre c.crisis c.LTRO) $periods $seasonal) if amihud_nach<100, absorb($FE) vce($SE1)  old
est sto t2_1e`j'
reghdfe rate_wins	nachmittag c.nachmittag#(`h2'#(c.pre c.crisis c.LTRO) $control0a $control0b $control1 $control2 $control3 $control4 $control5 $control6 $control7 $periods $seasonal) if amihud_nach<100, absorb($FE) vce($SE1)  old
est sto t2_1f`j'
*robustness table
reghdfe rate_wins 	ext	c.ext#($periods2) nachmittag c.nachmittag#(`h2' c.ext c.ext#($periods2) $periods $seasonal) if amihud_nach<100, absorb($FE) vce($SE1)  old
est sto t2_5a`j'
reghdfe rate_wins 	ext	c.ext#($periods2) nachmittag `h2'#c.ext c.nachmittag#(`h2' `h2'#c.ext c.ext c.ext#($periods2)  $periods $seasonal) if amihud_nach<100, absorb($FE) vce($SE1)  old
est sto t2_5b`j'
reghdfe rate_wins nachmittag c.nachmittag#(`h2' $seasonal) if amihud_nach<100 & LTRO==1, absorb($FE) vce($SE1)  old
est sto t2_5c`j'
reghdfe rate_wins nachmittag c.nachmittag#(`h2' $seasonal) if amihud_nach<100 & LTRO1y==1, absorb($FE) vce($SE1)  old
est sto t2_5d1`j'
reghdfe rate_wins nachmittag c.nachmittag#(`h2' $seasonal) if amihud_nach<100 & LTRO3y==1, absorb($FE) vce($SE1)  old
est sto t2_5d2`j'
reghdfe rate_wins 		c.nachmittag##(`h2' $control12 $periods $seasonal) if amihud_nach<100, absorb($FE2) vce($SE1)  old
est sto t2_5e`j'
reghdfe rate_wins 		c.nachmittag##(`h1' $control12 $periods $seasonal) if damihud<500 & amihud_nach<100, absorb($FE2) vce($SE1)  old
est sto t2_5f`j'
local h6 = "$" + "liqu" + "`j'" + "a"
local h7 = "$" + "liqu" + "`j'" + "d"
local h8 = "$" + "liqu" + "`j'" + "help1"
local h9 = "$" + "liqu" + "`j'" + "help2"
reghdfe rate_wins 		nachmittag c.nachmittag#(`h6'#`h8' `h6'#`h9' $periods $seasonal) if  amihud_nach<100, absorb($FE) vce($SE1)  old
est sto t2_5g`j'
}

*step 2 baseline
outreg2 [t2_1a3 t2_1b3 t2_1c3 t2_1d3 t2_1e3 t2_1f3] using "R:\Zentrale\ZB-F\Daten\F 1\Projekte\Abbassi-Tischer\Replication\Tables\step2_doubleclusterSE_baseline", stats(coef se) e(r2_within)   replace excel alpha(0.01, 0.05) symbol(**, *)
outreg2 [t2_1a1 t2_1a2 t2_1a4 t2_1a5 t2_1b1 t2_1b2 t2_1b4 t2_1b5 t2_1c1 t2_1c2 t2_1c4 t2_1c5 t2_1d1 t2_1d2 t2_1d4 t2_1d5 t2_1e1 t2_1e2 t2_1e4 t2_1e5 t2_1f1 t2_1f2 t2_1f4 t2_1f5] using "R:\Zentrale\ZB-F\Daten\F 1\Projekte\Abbassi-Tischer\Replication\Tables\step2_doubleclusterSE_baseline_otherliqu", stats(coef se) e(r2_within)   replace excel alpha(0.01, 0.05) symbol(**, *)

*step 2 robustness
outreg2 [t2_5a3 t2_5b3 t2_5c3 t2_5d13 t2_5d23 t2_5e3 t2_5f3 t2_5g3] using "R:\Zentrale\ZB-F\Daten\F 1\Projekte\Abbassi-Tischer\Replication\Tables\step2_doubleclusterSE_robust", stats(coef se) e(r2_within)   replace excel alpha(0.01, 0.05) symbol(**, *)
outreg2 [t2_5a1 t2_5a2 t2_5a4 t2_5a5 t2_5b1 t2_5b2 t2_5b4 t2_5b5 t2_5c1 t2_5c2 t2_5c4 t2_5c5 t2_5d11 t2_5d12  t2_5d14 t2_5d15 t2_5d21 t2_5d22  t2_5d24 t2_5d25 t2_5e1 t2_5e2 t2_5e4 t2_5e5 t2_5f1 t2_5f2 t2_5f4 t2_5f5 t2_5g1 t2_5g2 t2_5g4 t2_5g5] using "R:\Zentrale\ZB-F\Daten\F 1\Projekte\Abbassi-Tischer\Replication\Tables\step2_doubleclusterSE_robust_otherliqu", stats(coef se) e(r2_within)   replace excel alpha(0.01, 0.05) symbol(**, *)


********************************************************************************************************************************************************************************************************************************************************************
********************************************************************************************************************************************************************************************************************************************************************
*Step1 Estimating the intraday term structure
********************************************************************************************************************************************************************************************************************************************************************
********************************************************************************************************************************************************************************************************************************************************************
keep if amihud_nach<100

egen blperiodFE = group(bankid timeframe group)
egen blFE = group(bankid group)
gen end_rmp = (d_to_rmp==1)
label var end_rmp "=last day of reserve maintenance period = 1"
gen first_rmp = (d_in_rmp==1)
label var first_rmp "=first day of reserve maintenance period = 1"
 

 *Equation 3 ganzer Zeitraum
reg rate_diff t_dummy2-t_dummy8, vce($SE)
est store m0ro
areg rate_diff t_dummy2-t_dummy8, absorb(blFE) vce($SE)
est store m0_c1r
areg rate_diff t_dummy2-t_dummy8 c.(t_dummy2-t_dummy8)#c.(end_rmp first_rmp end_month end_year), absorb(blFE) vce($SE)
est store m0_c2r

forvalues j = 1/5 {
areg rate_diff t_dummy2-t_dummy8 if timeframe_indicator==`j', absorb(blFE) vce($SE)
est store m`j'ro
areg rate_diff t_dummy2-t_dummy8 c.(t_dummy2-t_dummy8)#c.(end_rmp first_rmp end_month end_year) if timeframe_indicator==`j', absorb(blFE) vce($SE)
est store m`j'_cr
}


outreg2 [ m0ro m0_c1r m0_c2r m1ro m1_cr m2ro m2_cr m3ro m3_cr m4ro m4_cr m5ro m5_cr] using "R:\Zentrale\ZB-F\Daten\F 1\Projekte\Abbassi-Tischer\Replication\Tables\step1_robustSE", replace stats(coef se) e(r2_a) ///
							  label bdec(4) sdec(3) excel alpha(0.01, 0.05) symbol(**, *)  
							  
cgmreg rate_diff t_dummy2-t_dummy8, cluster(bankid tdate)
est store m0
cgmreg rate_diff t_dummy2-t_dummy8 i.blFE, cluster(bankid tdate)
est store m0_c1
cgmreg rate_diff t_dummy2-t_dummy8 c.(t_dummy2-t_dummy8)#c.(end_rmp first_rmp end_month end_year) i.blFE, cluster(bankid tdate)
est store m0_c2

forvalues j = 1/5 {
cgmreg rate_diff t_dummy2-t_dummy8 i.blFE if timeframe_indicator==`j', cluster(bankid tdate)
est store m`j'
cgmreg rate_diff t_dummy2-t_dummy8 c.(t_dummy2-t_dummy8)#c.(end_rmp first_rmp end_month end_year) i.blFE if timeframe_indicator==`j', cluster(bankid tdate)
est store m`j'_c
}

outreg2 [ m0 m0_c1 m0_c2 m1 m1_c m2 m2_c m3 m3_c m4 m4_c m5 m5_c] using "R:\Zentrale\ZB-F\Daten\F 1\Projekte\Abbassi-Tischer\Replication\Tables\step1_doubleclusterSE", replace stats(coef se) e(r2_a) ///
							  label bdec(4) sdec(3) excel alpha(0.01, 0.05) symbol(**, *)  
							  
estimates clear
cgmreg rate_diff t_dummy1-t_dummy7, cluster(bankid tdate)
est store m0
cgmreg rate_diff t_dummy1-t_dummy7 i.blFE, cluster(bankid tdate)
est store m0_c1
cgmreg rate_diff t_dummy1-t_dummy7 c.(t_dummy1-t_dummy7)#c.(end_rmp first_rmp end_month end_year) i.blFE, cluster(bankid tdate)
est store m0_c2
forvalues j=1/5 {
cgmreg rate_diff t_dummy1-t_dummy7 i.blFE if timeframe_indicator==`j', cluster(bankid tdate)
est store m`j'
cgmreg rate_diff t_dummy1-t_dummy7 c.(t_dummy1-t_dummy7)#c.(end_rmp first_rmp end_month end_year) i.blFE if timeframe_indicator==`j', cluster(bankid tdate)
est store m`j'_c
}
outreg2 [ m0 m0_c1 m0_c2 m1 m1_c m2 m2_c m3 m3_c m4 m4_c m5 m5_c] using "R:\Zentrale\ZB-F\Daten\F 1\Projekte\Abbassi-Tischer\Replication\Tables\step1_doubleclusterSE_firstcoeff", replace stats(coef se) e(r2_a) ///
							  label bdec(4) sdec(3) excel alpha(0.01, 0.05) symbol(**, *)  


estimates clear

*hourly daily rate:
cgmreg rate_diff t, cluster(bankid tdate)
est store m0ro
cgmreg rate_diff t i.blFE, cluster(bankid tdate)
est store m0_c1r
cgmreg rate_diff t c.t#c.(end_rmp first_rmp end_month end_year) i.blFE, cluster(bankid tdate)
est store m0_c2r

forvalues j = 1/5 {
cgmreg rate_diff t i.blFE if timeframe_indicator==`j', cluster(bankid tdate)
est store m`j'ro
cgmreg rate_diff t c.t#c.(end_rmp first_rmp end_month end_year) i.blFE if timeframe_indicator==`j', cluster(bankid tdate)
est store m`j'_cr
}

outreg2 [ m0ro m0_c1r m0_c2r m1ro m1_cr m2ro m2_cr m3ro m3_cr m4ro m4_cr m5ro m5_cr] using "R:\Zentrale\ZB-F\Daten\F 1\Projekte\Abbassi-Tischer\Replication\Tables\step1_dailyrate", replace stats(coef se) e(r2_a) ///
							  label bdec(4) sdec(3) excel alpha(0.01, 0.05) symbol(**, *)  

  
**********************************************************************************************************************************************************************************************************************************************************************************************************************************************
**********************************************************************************************************************************************************************************************************************************************************************************************************************************************
*Graphs							  
**********************************************************************************************************************************************************************************************************************************************************************************************************************************************
**********************************************************************************************************************************************************************************************************************************************************************************************************************************************

cap drop fit* conf_*
**********************************************************************************************************************************
**********************************************************************************************************************************
*The intraday term structure
**********************************************************************************************************************************
**********************************************************************************************************************************
gen conf_down = .
label var conf_down "95% confidence band"
gen conf_up = .
label var conf_up "95% confidence band"


areg rate_diff t_dummy2-t_dummy8 c.(t_dummy2-t_dummy8)#c.(end_rmp first_rmp end_month end_year), absorb(blFE) vce($SE)

quietly {
cap drop fit
replace conf_down = 0
replace conf_up = 0
forvalues i=2/8 {
lincom _cons + t_dummy`i'
replace conf_down = r(estimate)-1.96*r(se) if t_dummy`i'==1
replace conf_up= r(estimate)+1.96*r(se) if t_dummy`i'==1
}
lincom _cons
replace conf_down = r(estimate)-1.96*r(se) if t==0 /*t==0 entspricht hour==8, also dem ersten time band*/
replace conf_up = r(estimate)+1.96*r(se) if t==0

gen fit = _b[_cons] + _b[t_dummy2]*t_dummy2 + _b[t_dummy3]*t_dummy3 + _b[t_dummy4]*t_dummy4 + _b[t_dummy5]*t_dummy5 + _b[t_dummy6]*t_dummy6 + _b[t_dummy7]*t_dummy7 + _b[t_dummy8]*t_dummy8
label var fit "Intraday interest rate"
}
preserve
duplicates drop hour, force
tw (connected fit hour, sort(hour) clcolor(black)) (line conf_down hour, sort(hour) clcolor(red)) (line conf_up hour, sort(hour) clcolor(red)), ytitle("Basis points") legend(off) ylabel(2(2)-4,grid gmin gmax) xlabel(#4,val) name("intraday_06_12",replace) /*title("Intraday Interest Pattern FE+C, 21.11.2011-27.6.2012")*/
graph export "R:\Zentrale\ZB-F\Daten\F 1\Projekte\Abbassi-Tischer\Replication\Graphs\intraday_rate_obsright_06-12.png", replace name("intraday_06_12")							  
graph export "R:\Zentrale\ZB-F\Daten\F 1\Projekte\Abbassi-Tischer\Replication\Graphs\intraday_rate_obsright_06-12.eps", replace name("intraday_06_12")							  
restore
cap drop fit




forvalues j = 1/5 {
areg rate_diff t_dummy2-t_dummy8 c.(t_dummy2-t_dummy8)#c.(end_rmp first_rmp end_month end_year) if timeframe_indicator==`j', absorb(blFE) vce($SE)

*quietly {
replace conf_down = 0
replace conf_up = 0
forvalues i=2/8 {
lincom _cons + t_dummy`i'
replace conf_down = r(estimate)-1.96*r(se) if t_dummy`i'==1
replace conf_up= r(estimate)+1.96*r(se) if t_dummy`i'==1
}
lincom _cons
replace conf_down = r(estimate)-1.96*r(se) if t==0 /*t==0 entspricht hour==8, also dem ersten time band*/
replace conf_up = r(estimate)+1.96*r(se) if t==0

gen fit`j' = _b[_cons] + _b[t_dummy2]*t_dummy2 + _b[t_dummy3]*t_dummy3 + _b[t_dummy4]*t_dummy4 + _b[t_dummy5]*t_dummy5 + _b[t_dummy6]*t_dummy6 + _b[t_dummy7]*t_dummy7 + _b[t_dummy8]*t_dummy8
label var fit`j' "Intraday interest rate"
*}
preserve
duplicates drop hour timeframe_indicator, force
tw (connected fit`j' hour if timeframe_indicator==`j', sort(hour) clcolor(black)) (line conf_down hour if timeframe_indicator==`j', sort(hour) clcolor(red)) (line conf_up hour if timeframe_indicator==`j', sort(hour) clcolor(red)), ytitle("Basis points") legend(off) ylabel(2(2)-4,grid gmin gmax) xlabel(#4,val) name("intraday_tf`j'",replace) /*title("Intraday Interest Pattern FE+C, 21.11.2011-27.6.2012")*/
graph export "R:\Zentrale\ZB-F\Daten\F 1\Projekte\Abbassi-Tischer\Replication\Graphs\intraday_rate_obsright_tf`j'.png", replace name("intraday_tf`j'")							  
graph export "R:\Zentrale\ZB-F\Daten\F 1\Projekte\Abbassi-Tischer\Replication\Graphs\intraday_rate_obsright_tf`j'.eps", replace name("intraday_tf`j'")							  
restore
}
preserve
duplicates drop hour, force
tw (connected fit1 hour, sort(hour) ) (connected fit2 hour, msymbol(D) sort(hour) ) (connected fit3 hour, msymbol(S) sort(hour) ) (connected fit4 hour,msymbol(+) sort(hour) ) (connected fit5 hour,msymbol(T) sort(hour) ), ///
legend(label(1 "Pre crisis") label(2 "Crisis") label(3 "LTRO 1y") label(4 "Sov debt crisis") label(5 "LTRO 3y")) xlabel(#4, valuelabel) ylabel(-4(2)2) yscale(range(-4 2)) ytitle(Basis points) name("intraday_alltf",replace)
graph export "R:\Zentrale\ZB-F\Daten\F 1\Projekte\Abbassi-Tischer\Replication\Graphs\intraday_rate_obsright_alltf.png", replace name("intraday_alltf")							  
graph export "R:\Zentrale\ZB-F\Daten\F 1\Projekte\Abbassi-Tischer\Replication\Graphs\intraday_rate_obsright_alltf.eps", replace name("intraday_alltf")							  
restore

**********************************************************************************************************************************
**********************************************************************************************************************************
*Intraday Rate per Basket
**********************************************************************************************************************************
**********************************************************************************************************************************
cap drop help*
bysort tdate ext: egen damount_bas = total(amount)
bysort tdate ext: egen help1 = total(rate*amount)
gen dav_rate_bas  = help1/damount_bas
gen rate_diff_bas = rate-dav_rate_bas

gen conf_down_bas=.
gen conf_up_bas=.


areg rate_diff c.ext##c.(t_dummy2-t_dummy8 c.(end_rmp first_rmp end_month end_year)#c.(t_dummy2-t_dummy8)) if  tdate>=td(24nov2008), absorb(blperiodFE) vce($SE)
cap drop fitecb2 fitext2
gen fitecb2 = _b[_cons] + _b[t_dummy2]*t_dummy2 + _b[t_dummy3]*t_dummy3 + _b[t_dummy4]*t_dummy4 + _b[t_dummy5]*t_dummy5 + _b[t_dummy6]*t_dummy6 + _b[t_dummy7]*t_dummy7 + _b[t_dummy8]*t_dummy8
gen fitext2 = _b[_cons] + _b[t_dummy2]*t_dummy2 + _b[t_dummy3]*t_dummy3 + _b[t_dummy4]*t_dummy4 + _b[t_dummy5]*t_dummy5 + _b[t_dummy6]*t_dummy6 + _b[t_dummy7]*t_dummy7 + _b[t_dummy8]*t_dummy8 ///
+ _b[ext]*ext + _b[c.ext#c.t_dummy2]*ext*t_dummy2 + _b[c.ext#c.t_dummy3]*ext*t_dummy3 + _b[c.ext#c.t_dummy4]*ext*t_dummy4 + _b[c.ext#c.t_dummy5]*ext*t_dummy5 + _b[c.ext#c.t_dummy6]*ext*t_dummy6 + _b[c.ext#c.t_dummy7]*ext*t_dummy7 + _b[c.ext#c.t_dummy8]*ext*t_dummy8
qui forvalues i=2/8 {
lincom _cons + t_dummy`i'
replace conf_down_bas = r(estimate)-1.96*r(se) if t_dummy`i'==1 & basket==1
replace conf_up_bas= r(estimate)+1.96*r(se) if t_dummy`i'==1 & basket==1
lincom _cons + ext + t_dummy`i' + c.ext#c.t_dummy`i'
replace conf_down_bas = r(estimate)-1.96*r(se) if t_dummy`i'==1 & basket==2
replace conf_up_bas= r(estimate)+1.96*r(se) if t_dummy`i'==1 & basket==2
}
lincom _cons
replace conf_down_bas = r(estimate)-1.96*r(se) if t==0 /*t==0 entspricht hour==8, also dem ersten time band*/ & basket==1
replace conf_up_bas = r(estimate)+1.96*r(se) if t==0 & basket==1
lincom _cons + ext
replace conf_down_bas = r(estimate)-1.96*r(se) if t==0 /*t==0 entspricht hour==8, also dem ersten time band*/ & basket==2
replace conf_up_bas = r(estimate)+1.96*r(se) if t==0 & basket==2

preserve
duplicates drop hour basket, force
tw (connected fitecb2 hour if basket==1, sort(hour) clcolor(black)) (connected fitext2 hour if basket==2, sort(hour) yaxis(2) msymbol(D) clcolor(black)) (line conf_down_bas hour if basket==1, sort(hour)  ///
clpattern(dash) clcolor(blue)) (line conf_up_bas hour if basket==1,  sort(hour) clpattern(dash) clcolor(blue)) (line conf_down_bas hour if basket==2, sort(hour) yaxis(2) clpattern(shortdash_dot) clcolor(red)) ///
(line conf_up_bas hour if basket==2, sort(hour) yaxis(2) clpattern(shortdash_dot) clcolor(red)), name("all_days_bas2",replace) ylabel(2(2)-4,grid gmin gmax) xlabel(#4,val) ///
ylabel(0(2)6, axis(2)) yscale(range(0 6) axis(2)) ytitle("Narrow basket (Basis points)")  ytitle("Extended basket (Basis points)", axis(2)) ///
legend(order(1 4 2 5 ) label(1 "Narrow basket") label(4 "Extended basket") label(2 "Narrow 95% conf band") label(3 "") label(5 "Extended 95% conf band") label(6 ""))
*ylabel(-4(2)2) yscale(range(-4 2)) 
restore

graph export "R:\Zentrale\ZB-F\Daten\F 1\Projekte\Abbassi-Tischer\Replication\Graphs\intrarate_baskets_withintercept_allfe.png", replace
graph export "R:\Zentrale\ZB-F\Daten\F 1\Projekte\Abbassi-Tischer\Replication\Graphs\intrarate_baskets_withintercept_allfe.eps", replace


**********************************************************************************************************************************
**********************************************************************************************************************************
*Intraday Interest Rate with weighted/unweighted daily average rate
**********************************************************************************************************************************
**********************************************************************************************************************************
*estimate the intraday rate using the difference to the equal weighted daily average rate.
*deviation equal to value weighted daily average rate
bysort tdate: egen avrate = mean(rate)
preserve
duplicates drop tdate, force
corr avrate drate_av_vol
reg avrate drate_av_vol
gen ddd = avrate-drate_av_vol
gen dddperc = (avrate-drate_av_vol)/avrate*100
tw line dddperc tdate,sort
gen absd = abs(ddd)
gen absdperc = abs(dddperc)
su absd ddd absdperc dddperc
restore
*mean absolute deviation is .43 bps or .49%. corrcoeff is essentially 1.


gen rate_diff_equw = rate - avrate
gen conf_down_equw=.
gen conf_up_equw=.
gen fitequw=.
gen conf_down_vw=.
gen conf_up_vw=.
gen fitvw=.

areg rate_diff_equw t_dummy2-t_dummy8 c.(t_dummy2-t_dummy8)#c.(end_rmp first_rmp end_month end_year), absorb(blperiodFE) vce($SE)
replace fitequw = _b[_cons] + _b[t_dummy2]*t_dummy2 + _b[t_dummy3]*t_dummy3 + _b[t_dummy4]*t_dummy4 + _b[t_dummy5]*t_dummy5 + _b[t_dummy6]*t_dummy6 + _b[t_dummy7]*t_dummy7 + _b[t_dummy8]*t_dummy8
qui forvalues i=2/8 {
lincom _cons + t_dummy`i'
replace conf_down_equw = r(estimate)-1.96*r(se) if t_dummy`i'==1
replace conf_up_equw= r(estimate)+1.96*r(se) if t_dummy`i'==1 
}
lincom _cons
replace conf_down_equw = r(estimate)-1.96*r(se) if t==0 /*t==0 entspricht hour==8, also dem ersten time band*/
replace conf_up_equw = r(estimate)+1.96*r(se) if t==0 

areg rate_diff t_dummy2-t_dummy8 c.(t_dummy2-t_dummy8)#c.(end_rmp first_rmp end_month end_year), absorb(blperiodFE) vce($SE)
replace fitvw = _b[_cons] + _b[t_dummy2]*t_dummy2 + _b[t_dummy3]*t_dummy3 + _b[t_dummy4]*t_dummy4 + _b[t_dummy5]*t_dummy5 + _b[t_dummy6]*t_dummy6 + _b[t_dummy7]*t_dummy7 + _b[t_dummy8]*t_dummy8
qui forvalues i=2/8 {
lincom _cons + t_dummy`i'
replace conf_down_vw = r(estimate)-1.96*r(se) if t_dummy`i'==1
replace conf_up_vw= r(estimate)+1.96*r(se) if t_dummy`i'==1 
}
lincom _cons
replace conf_down_vw = r(estimate)-1.96*r(se) if t==0 /*t==0 entspricht hour==8, also dem ersten time band*/ 
replace conf_up_vw = r(estimate)+1.96*r(se) if t==0 

preserve
duplicates drop hour,force
tw (connected fitequw hour, sort(hour) clcolor(black)) (connected fitvw hour, sort(hour) msymbol(D) clcolor(black))  (line conf_down_equw hour, sort(hour) clpattern(dash) clcolor(blue)) (line conf_up_equw hour,  sort(hour) clpattern(dash) clcolor(blue)) ///
(line conf_down_vw hour, sort(hour) clpattern(shortdash_dot) clcolor(red)) (line conf_up_vw hour,  sort(hour) clpattern(shortdash_dot) clcolor(red)), ///
name("all_days_equw",replace) /*title("Intraday Interest Patterns / equal and value weighted average")*/ ytitle("Basis points") ylabel(2(2)-4,grid gmin gmax) xlabel(#4,val) ///
legend(order(1 2 3 5) label(1 "Intraday rate no weights") label(2 "Intraday rate vol weights") label(3 "No weights 95% conf band") label(4 "")  label(5 "Vol weights 95% conf band") label(6 ""))

graph export "R:\Zentrale\ZB-F\Daten\F 1\Projekte\Abbassi-Tischer\Replication\Graphs\intrarate_equalvalueweight_allfe.png", replace
graph export "R:\Zentrale\ZB-F\Daten\F 1\Projekte\Abbassi-Tischer\Replication\Graphs\intrarate_equalvalueweight_allfe.eps", replace
restore
